"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.kafka.v1.connector_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the connector belongs to.

    To get this ID, make a [ClusterService.List] request.
    """
    connector_name: builtins.str
    """Name of the Apache Kafka® connector to return information about.

    To get this name, make a [ConnectorService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___GetConnectorRequest = GetConnectorRequest

@typing.final
class ListConnectorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to list connectors in.

    To get this ID, make a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the API returns a [ListConnectorsResponse.next_page_token] that can be used to get the next page of results in the subsequent [ConnectorService.List] requests.
    """
    page_token: builtins.str
    """Page token that can be used to iterate through multiple pages of results.

    To get the next page of results, set [page_token] to the [ListConnectorsResponse.next_page_token] returned by the previous [ConnectorService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListConnectorsRequest = ListConnectorsRequest

@typing.final
class ListConnectorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTORS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """The token that can be used to get the next page of results.

    If the number of results is larger than [ListConnectorsRequest.page_size], use the [next_page_token] as the value for the [ListConnectorsRequest.page_token] in the subsequent [ConnectorService.List] request to iterate through multiple pages of results.
    """
    @property
    def connectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.kafka.v1.connector_pb2.Connector]:
        """List of Apache Kafka® Connectors."""

    def __init__(
        self,
        *,
        connectors: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.connector_pb2.Connector] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connectors", b"connectors", "next_page_token", b"next_page_token"]) -> None: ...

global___ListConnectorsResponse = ListConnectorsResponse

@typing.final
class CreateConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to create the connector in.

    To get this ID, make a [ClusterService.List] request.
    """
    @property
    def connector_spec(self) -> yandex.cloud.mdb.kafka.v1.connector_pb2.ConnectorSpec:
        """Configuration of the connector to create."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_spec: yandex.cloud.mdb.kafka.v1.connector_pb2.ConnectorSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector_spec", b"connector_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_spec", b"connector_spec"]) -> None: ...

global___CreateConnectorRequest = CreateConnectorRequest

@typing.final
class CreateConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the connector is being created in."""
    connector_name: builtins.str
    """Name of the Apache Kafka® connector that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___CreateConnectorMetadata = CreateConnectorMetadata

@typing.final
class UpdateConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    CONNECTOR_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to update the connector in.

    To get this ID, make a [ClusterService.List] request.
    """
    connector_name: builtins.str
    """Name of the connector to update.

    To get this name, make a [ConnectorService.List] request.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which settings of the connector should be updated."""

    @property
    def connector_spec(self) -> yandex.cloud.mdb.kafka.v1.connector_pb2.UpdateConnectorSpec:
        """Configuration of the connector to update."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        connector_spec: yandex.cloud.mdb.kafka.v1.connector_pb2.UpdateConnectorSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector_spec", b"connector_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name", "connector_spec", b"connector_spec", "update_mask", b"update_mask"]) -> None: ...

global___UpdateConnectorRequest = UpdateConnectorRequest

@typing.final
class UpdateConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the connector is being updated in."""
    connector_name: builtins.str
    """Name of the Apache Kafka® connector that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___UpdateConnectorMetadata = UpdateConnectorMetadata

@typing.final
class DeleteConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to delete the connector from.

    To get this ID, make a [ClusterService.List] request.
    """
    connector_name: builtins.str
    """Name of the connector to delete.

    To get this name, make a [ConnectorService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___DeleteConnectorRequest = DeleteConnectorRequest

@typing.final
class DeleteConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the connector is being deleted from."""
    connector_name: builtins.str
    """Name of the Apache Kafka® connector that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___DeleteConnectorMetadata = DeleteConnectorMetadata

@typing.final
class ResumeConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to resume the connector in.

    To get this ID, make a [ClusterService.List] request.
    """
    connector_name: builtins.str
    """Name of the Apache Kafka® connector to resume.

    To get this name, make a [ConnectorService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___ResumeConnectorRequest = ResumeConnectorRequest

@typing.final
class ResumeConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the connector is being resumed in."""
    connector_name: builtins.str
    """Name of the Apache Kafka® connector that is beign resumed."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___ResumeConnectorMetadata = ResumeConnectorMetadata

@typing.final
class PauseConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to pause the connector in.

    To get this ID, make a [ClusterService.List] request.
    """
    connector_name: builtins.str
    """Name of the Apache Kafka® connector to pause.

    To get this name, make a [ConnectorService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___PauseConnectorRequest = PauseConnectorRequest

@typing.final
class PauseConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the connector is being paused in."""
    connector_name: builtins.str
    """Name of the Apache Kafka® connector that is being paused."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        connector_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connector_name", b"connector_name"]) -> None: ...

global___PauseConnectorMetadata = PauseConnectorMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/mdb/kafka/v1/common.proto\x12\x19yandex.cloud.mdb.kafka.v1*\xe2\x01\n\x0f\x43ompressionType\x12 \n\x1c\x43OMPRESSION_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1d\x43OMPRESSION_TYPE_UNCOMPRESSED\x10\x01\x12\x19\n\x15\x43OMPRESSION_TYPE_ZSTD\x10\x02\x12\x18\n\x14\x43OMPRESSION_TYPE_LZ4\x10\x03\x12\x1b\n\x17\x43OMPRESSION_TYPE_SNAPPY\x10\x04\x12\x19\n\x15\x43OMPRESSION_TYPE_GZIP\x10\x05\x12\x1d\n\x19\x43OMPRESSION_TYPE_PRODUCER\x10\x06*s\n\rSaslMechanism\x12\x1e\n\x1aSASL_MECHANISM_UNSPECIFIED\x10\x00\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_256\x10\x01\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_512\x10\x02\x42\x64\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _globals['_COMPRESSIONTYPE']._serialized_start=70
  _globals['_COMPRESSIONTYPE']._serialized_end=296
  _globals['_SASLMECHANISM']._serialized_start=298
  _globals['_SASLMECHANISM']._serialized_end=413
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PublishRegistryDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of registry publishing message"""
    topic: builtins.str
    """Topic where message should be published"""
    data: builtins.bytes
    """Content of the message"""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        topic: builtins.str = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "registry_id", b"registry_id", "topic", b"topic"]) -> None: ...

global___PublishRegistryDataRequest = PublishRegistryDataRequest

@typing.final
class PublishRegistryDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishRegistryDataResponse = PublishRegistryDataResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/mysql.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/datatransfer/v1/endpoint/mysql.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\x8e\x01\n\x0eOnPremiseMysql\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\x12\r\n\x05hosts\x18\x05 \x03(\t\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSModeJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\"\x86\x01\n\x0fMysqlConnection\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysqlH\x00\x42\x0c\n\nconnection\"\xcd\x02\n\x1bMysqlObjectTransferSettings\x12H\n\x04view\x18\x01 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07routine\x18\x02 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07trigger\x18\x03 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12J\n\x06tables\x18\x04 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\"\xad\x03\n\x0bMysqlSource\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MysqlConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x64\n\x18object_transfer_settings\x18\x0b \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings\x12\x1c\n\x14include_tables_regex\x18\x0c \x03(\t\x12\x1c\n\x14\x65xclude_tables_regex\x18\r \x03(\t\x12\x17\n\x0fsecurity_groups\x18\x0e \x03(\t\x12\x18\n\x10service_database\x18\x0f \x01(\tJ\x04\x08\x05\x10\x08J\x04\x08\t\x10\x0b\"\x85\x03\n\x0bMysqlTarget\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MysqlConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x10\n\x08sql_mode\x18\x05 \x01(\t\x12\x1e\n\x16skip_constraint_checks\x18\x06 \x01(\x08\x12\x10\n\x08timezone\x18\x07 \x01(\t\x12L\n\x0e\x63leanup_policy\x18\x08 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicy\x12\x18\n\x10service_database\x18\x0f \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x10 \x03(\tJ\x04\x08\t\x10\x0f\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_ONPREMISEMYSQL']._serialized_start=145
  _globals['_ONPREMISEMYSQL']._serialized_end=287
  _globals['_MYSQLCONNECTION']._serialized_start=290
  _globals['_MYSQLCONNECTION']._serialized_end=424
  _globals['_MYSQLOBJECTTRANSFERSETTINGS']._serialized_start=427
  _globals['_MYSQLOBJECTTRANSFERSETTINGS']._serialized_end=760
  _globals['_MYSQLSOURCE']._serialized_start=763
  _globals['_MYSQLSOURCE']._serialized_end=1192
  _globals['_MYSQLTARGET']._serialized_start=1195
  _globals['_MYSQLTARGET']._serialized_end=1584
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.tts.v3.tts_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SynthesizerStub:
    """A set of methods for voice synthesis."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    UtteranceSynthesis: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisRequest,
        yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisResponse,
    ]
    """Synthesizing text into speech."""

class SynthesizerAsyncStub:
    """A set of methods for voice synthesis."""

    UtteranceSynthesis: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisRequest,
        yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisResponse,
    ]
    """Synthesizing text into speech."""

class SynthesizerServicer(metaclass=abc.ABCMeta):
    """A set of methods for voice synthesis."""

    @abc.abstractmethod
    def UtteranceSynthesis(
        self,
        request: yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisResponse], collections.abc.AsyncIterator[yandex.cloud.ai.tts.v3.tts_pb2.UtteranceSynthesisResponse]]:
        """Synthesizing text into speech."""

def add_SynthesizerServicer_to_server(servicer: SynthesizerServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/service_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/iam/v1/service_account.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x02\n\x0eServiceAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12?\n\x06labels\x18\x06 \x03(\x0b\x32/.yandex.cloud.iam.v1.ServiceAccount.LabelsEntry\x12\x39\n\x15last_authenticated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42V\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.service_account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _SERVICEACCOUNT_LABELSENTRY._options = None
  _SERVICEACCOUNT_LABELSENTRY._serialized_options = b'8\001'
  _globals['_SERVICEACCOUNT']._serialized_start=100
  _globals['_SERVICEACCOUNT']._serialized_end=401
  _globals['_SERVICEACCOUNT_LABELSENTRY']._serialized_start=356
  _globals['_SERVICEACCOUNT_LABELSENTRY']._serialized_end=401
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.playlist_pb2
import yandex.cloud.video.v1.playlist_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PlaylistServiceStub:
    """Playlist management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistRequest,
        yandex.cloud.video.v1.playlist_pb2.Playlist,
    ]
    """Returns the specific playlist."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsRequest,
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse,
    ]
    """List playlists for a channel."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.CreatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create playlist."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.UpdatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update playlist."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.DeletePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete playlist."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.BatchDeletePlaylistsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete playlist."""

    GetPlayerURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLRequest,
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse,
    ]
    """Returns player's url."""

class PlaylistServiceAsyncStub:
    """Playlist management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistRequest,
        yandex.cloud.video.v1.playlist_pb2.Playlist,
    ]
    """Returns the specific playlist."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsRequest,
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse,
    ]
    """List playlists for a channel."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.CreatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create playlist."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.UpdatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update playlist."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.DeletePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete playlist."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.BatchDeletePlaylistsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete playlist."""

    GetPlayerURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLRequest,
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse,
    ]
    """Returns player's url."""

class PlaylistServiceServicer(metaclass=abc.ABCMeta):
    """Playlist management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.playlist_pb2.Playlist, collections.abc.Awaitable[yandex.cloud.video.v1.playlist_pb2.Playlist]]:
        """Returns the specific playlist."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse]]:
        """List playlists for a channel."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.CreatePlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create playlist."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.UpdatePlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update playlist."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.DeletePlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete playlist."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.BatchDeletePlaylistsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Batch delete playlist."""

    @abc.abstractmethod
    def GetPlayerURL(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse]]:
        """Returns player's url."""

def add_PlaylistServiceServicer_to_server(servicer: PlaylistServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.common.common_pb2
import yandex.cloud.ai.files.v1.file_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateFileRequest(google.protobuf.message.Message):
    """Request message for creating a new file."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    """Name of the file."""
    description: builtins.str
    """Description of the file."""
    mime_type: builtins.str
    """MIME type of the file, indicating the file's format (e.g., "application/pdf").
    If not specified, will be deduced automatically based on the file content.
    """
    content: builtins.bytes
    """Binary content of the file."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs to label the file."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """Expiration configuration for the file."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        mime_type: builtins.str = ...,
        content: builtins.bytes = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "description", b"description", "expiration_config", b"expiration_config", "folder_id", b"folder_id", "labels", b"labels", "mime_type", b"mime_type", "name", b"name"]) -> None: ...

global___CreateFileRequest = CreateFileRequest

@typing.final
class GetFileRequest(google.protobuf.message.Message):
    """Request message for retrieving a file by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    """ID of the file to retrieve."""
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id"]) -> None: ...

global___GetFileRequest = GetFileRequest

@typing.final
class GetFileUrlRequest(google.protobuf.message.Message):
    """Request message for retrieving the URL of a specific file."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    """ID of the file which the URL is requested."""
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id"]) -> None: ...

global___GetFileUrlRequest = GetFileUrlRequest

@typing.final
class GetFileUrlResponse(google.protobuf.message.Message):
    """Response message containing the URL to access the requested file."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL that can be used to access or download the file."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___GetFileUrlResponse = GetFileUrlResponse

@typing.final
class UpdateFileRequest(google.protobuf.message.Message):
    """Request message for updating an existing file."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FILE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    """ID of the file to update."""
    name: builtins.str
    """New name for the file."""
    description: builtins.str
    """New description for the file."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields to update."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """New expiration configuration for the file."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New set of labels for the file."""

    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expiration_config", b"expiration_config", "file_id", b"file_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFileRequest = UpdateFileRequest

@typing.final
class DeleteFileRequest(google.protobuf.message.Message):
    """Request message for deleting a file by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    """ID of the file to delete."""
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id"]) -> None: ...

global___DeleteFileRequest = DeleteFileRequest

@typing.final
class DeleteFileResponse(google.protobuf.message.Message):
    """Response message for the delete operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFileResponse = DeleteFileResponse

@typing.final
class ListFilesRequest(google.protobuf.message.Message):
    """Request message for listing files in a specific folder."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID from which to list files."""
    page_size: builtins.int
    """Maximum number of files to return per page."""
    page_token: builtins.str
    """Token to retrieve the next page of results."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFilesRequest = ListFilesRequest

@typing.final
class ListFilesResponse(google.protobuf.message.Message):
    """Response message for the list operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.files.v1.file_pb2.File]:
        """List of files in the specified folder."""

    def __init__(
        self,
        *,
        files: collections.abc.Iterable[yandex.cloud.ai.files.v1.file_pb2.File] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["files", b"files", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFilesResponse = ListFilesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OnPremiseMysql(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    port: builtins.int
    """Database port"""
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode:
        """TLS settings for server connection. Disabled by default."""

    def __init__(
        self,
        *,
        port: builtins.int = ...,
        subnet_id: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "port", b"port", "subnet_id", b"subnet_id", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremiseMysql = OnPremiseMysql

@typing.final
class MysqlConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    ON_PREMISE_FIELD_NUMBER: builtins.int
    mdb_cluster_id: builtins.str
    """Managed Service for MySQL cluster ID"""
    @property
    def on_premise(self) -> global___OnPremiseMysql:
        """Connection options for on-premise MySQL"""

    def __init__(
        self,
        *,
        mdb_cluster_id: builtins.str = ...,
        on_premise: global___OnPremiseMysql | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["mdb_cluster_id", "on_premise"] | None: ...

global___MysqlConnection = MysqlConnection

@typing.final
class MysqlObjectTransferSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    ROUTINE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Views

    CREATE VIEW ...
    """
    routine: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Routines

    CREATE PROCEDURE ... ; CREATE FUNCTION ... ;
    """
    trigger: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Triggers

    CREATE TRIGGER ...
    """
    tables: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    def __init__(
        self,
        *,
        view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        routine: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        trigger: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        tables: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routine", b"routine", "tables", b"tables", "trigger", b"trigger", "view", b"view"]) -> None: ...

global___MysqlObjectTransferSettings = MysqlObjectTransferSettings

@typing.final
class MysqlSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    OBJECT_TRANSFER_SETTINGS_FIELD_NUMBER: builtins.int
    INCLUDE_TABLES_REGEX_FIELD_NUMBER: builtins.int
    EXCLUDE_TABLES_REGEX_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SERVICE_DATABASE_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name

    You can leave it empty, then it will be possible to transfer tables from several
    databases at the same time from this source.
    """
    user: builtins.str
    """User for database access."""
    timezone: builtins.str
    """Database timezone

    Is used for parsing timestamps for saving source timezones. Accepts values from
    IANA timezone database. Default: local timezone.
    """
    service_database: builtins.str
    """Database for service tables

    Default: data source database. Here created technical tables (__tm_keeper,
    __tm_gtid_keeper).
    """
    @property
    def connection(self) -> global___MysqlConnection:
        """Database connection settings"""

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for database access."""

    @property
    def object_transfer_settings(self) -> global___MysqlObjectTransferSettings:
        """Schema migration

        Select database objects to be transferred during activation or deactivation.
        """

    @property
    def include_tables_regex(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def exclude_tables_regex(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        connection: global___MysqlConnection | None = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        timezone: builtins.str = ...,
        object_transfer_settings: global___MysqlObjectTransferSettings | None = ...,
        include_tables_regex: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_tables_regex: collections.abc.Iterable[builtins.str] | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        service_database: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "object_transfer_settings", b"object_transfer_settings", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "database", b"database", "exclude_tables_regex", b"exclude_tables_regex", "include_tables_regex", b"include_tables_regex", "object_transfer_settings", b"object_transfer_settings", "password", b"password", "security_groups", b"security_groups", "service_database", b"service_database", "timezone", b"timezone", "user", b"user"]) -> None: ...

global___MysqlSource = MysqlSource

@typing.final
class MysqlTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SQL_MODE_FIELD_NUMBER: builtins.int
    SKIP_CONSTRAINT_CHECKS_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SERVICE_DATABASE_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name

    Allowed to leave it empty, then the tables will be created in databases with the
    same names as on the source. If this field is empty, then you must fill below db
    schema for service table.
    """
    user: builtins.str
    """User for database access."""
    sql_mode: builtins.str
    """Default: NO_AUTO_VALUE_ON_ZERO,NO_DIR_IN_CREATE,NO_ENGINE_SUBSTITUTION."""
    skip_constraint_checks: builtins.bool
    """Disable constraints checks

    Recommend to disable for increase replication speed, but if schema contain
    cascading operations we don't recommend to disable. This option set
    FOREIGN_KEY_CHECKS=0 and UNIQUE_CHECKS=0.
    """
    timezone: builtins.str
    """Database timezone

    Is used for parsing timestamps for saving source timezones. Accepts values from
    IANA timezone database. Default: local timezone.
    """
    cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType
    """Cleanup policy

    Cleanup policy for activate, reactivate and reupload processes. Default is
    DISABLED.
    """
    service_database: builtins.str
    """Database schema for service table

    Default: db name. Here created technical tables (__tm_keeper, __tm_gtid_keeper).
    """
    @property
    def connection(self) -> global___MysqlConnection:
        """Database connection settings"""

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for database access."""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        connection: global___MysqlConnection | None = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        sql_mode: builtins.str = ...,
        skip_constraint_checks: builtins.bool = ...,
        timezone: builtins.str = ...,
        cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType = ...,
        service_database: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "connection", b"connection", "database", b"database", "password", b"password", "security_groups", b"security_groups", "service_database", b"service_database", "skip_constraint_checks", b"skip_constraint_checks", "sql_mode", b"sql_mode", "timezone", b"timezone", "user", b"user"]) -> None: ...

global___MysqlTarget = MysqlTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.api.v1.config.config_pb2
import yandex.cloud.loadtesting.api.v1.config_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ConfigServiceStub:
    """A set of methods for managing test configurations."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.CreateConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a test config in the specified folder."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.GetConfigRequest,
        yandex.cloud.loadtesting.api.v1.config.config_pb2.Config,
    ]
    """Returns the specified config.

    To get the list of all available configs, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsRequest,
        yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsResponse,
    ]
    """Retrieves the list of configs in the specified folder."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.DeleteConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified config."""

class ConfigServiceAsyncStub:
    """A set of methods for managing test configurations."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.CreateConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a test config in the specified folder."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.GetConfigRequest,
        yandex.cloud.loadtesting.api.v1.config.config_pb2.Config,
    ]
    """Returns the specified config.

    To get the list of all available configs, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsRequest,
        yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsResponse,
    ]
    """Retrieves the list of configs in the specified folder."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.config_service_pb2.DeleteConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified config."""

class ConfigServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing test configurations."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.loadtesting.api.v1.config_service_pb2.CreateConfigRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a test config in the specified folder."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.loadtesting.api.v1.config_service_pb2.GetConfigRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.config.config_pb2.Config, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.config.config_pb2.Config]]:
        """Returns the specified config.

        To get the list of all available configs, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.config_service_pb2.ListConfigsResponse]]:
        """Retrieves the list of configs in the specified folder."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.loadtesting.api.v1.config_service_pb2.DeleteConfigRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified config."""

def add_ConfigServiceServicer_to_server(servicer: ConfigServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActivateProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SKIP_DEFAULT_POLICY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Activate provider for Folder iD."""
    name: builtins.str
    """Activate specific provider by name.

    For more information, please see [activate-provider](/docs/backup/quickstart#activate-provider)
    """
    skip_default_policy: builtins.bool
    """Don't create default policies while activating the provider."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        skip_default_policy: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "name", b"name", "skip_default_policy", b"skip_default_policy"]) -> None: ...

global___ActivateProviderRequest = ActivateProviderRequest

@typing.final
class ActivateProviderMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Activate provider for folder specified by ID."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ActivateProviderMetadata = ActivateProviderMetadata

@typing.final
class ListActivatedProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to find out the backup provider."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListActivatedProvidersRequest = ListActivatedProvidersRequest

@typing.final
class ListActivatedProvidersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Name of the backup provider."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "names", b"names"]) -> None: ...

global___ListActivatedProvidersResponse = ListActivatedProvidersResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.assistants.v1.threads.message_pb2
import yandex.cloud.ai.assistants.v1.threads.thread_pb2
import yandex.cloud.ai.common.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateThreadRequest(google.protobuf.message.Message):
    """Request message for creating a new thread."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_AUTHOR_ID_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    """Name of the thread."""
    description: builtins.str
    """Description of the thread."""
    default_message_author_id: builtins.str
    """Default user ID that will be used as the author for thread messages if no other author is specified."""
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageData]:
        """List of messages to initialize the thread."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """Expiration configuration for the thread."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs to label the thread."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        messages: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageData] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        default_message_author_id: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_message_author_id", b"default_message_author_id", "description", b"description", "expiration_config", b"expiration_config", "folder_id", b"folder_id", "labels", b"labels", "messages", b"messages", "name", b"name"]) -> None: ...

global___CreateThreadRequest = CreateThreadRequest

@typing.final
class GetThreadRequest(google.protobuf.message.Message):
    """Request message for retrieving a thread by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THREAD_ID_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    """ID of the thread to retrieve."""
    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thread_id", b"thread_id"]) -> None: ...

global___GetThreadRequest = GetThreadRequest

@typing.final
class UpdateThreadRequest(google.protobuf.message.Message):
    """Request message for updating an existing thread."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    THREAD_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    """ID of the thread to update."""
    name: builtins.str
    """New name for the thread."""
    description: builtins.str
    """New description for the thread."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields to update."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """New expiration configuration for the thread."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New set of labels for the thread."""

    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expiration_config", b"expiration_config", "labels", b"labels", "name", b"name", "thread_id", b"thread_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateThreadRequest = UpdateThreadRequest

@typing.final
class DeleteThreadRequest(google.protobuf.message.Message):
    """Request message for deleting a thread by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THREAD_ID_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    """ID of the thread to delete."""
    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thread_id", b"thread_id"]) -> None: ...

global___DeleteThreadRequest = DeleteThreadRequest

@typing.final
class DeleteThreadResponse(google.protobuf.message.Message):
    """Response message for the delete operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteThreadResponse = DeleteThreadResponse

@typing.final
class ListThreadsRequest(google.protobuf.message.Message):
    """Request message for listing threads in a specific folder."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID from which to list threads."""
    page_size: builtins.int
    """Maximum number of threads to return per page."""
    page_token: builtins.str
    """Token to retrieve the next page of results."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListThreadsRequest = ListThreadsRequest

@typing.final
class ListThreadsResponse(google.protobuf.message.Message):
    """Response message for the list operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THREADS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def threads(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.threads.thread_pb2.Thread]:
        """List of threads in the specified folder."""

    def __init__(
        self,
        *,
        threads: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.threads.thread_pb2.Thread] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "threads", b"threads"]) -> None: ...

global___ListThreadsResponse = ListThreadsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ImageProductUsageServiceStub:
    """A set of methods for managing image product's usage."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Write: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageRequest,
        yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageResponse,
    ]
    """Writes image product's usage. Authentication is by user's service account."""

class ImageProductUsageServiceAsyncStub:
    """A set of methods for managing image product's usage."""

    Write: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageRequest,
        yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageResponse,
    ]
    """Writes image product's usage. Authentication is by user's service account."""

class ImageProductUsageServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing image product's usage."""

    @abc.abstractmethod
    def Write(
        self,
        request: yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageResponse, collections.abc.Awaitable[yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2.WriteImageProductUsageResponse]]:
        """Writes image product's usage. Authentication is by user's service account."""

def add_ImageProductUsageServiceServicer_to_server(servicer: ImageProductUsageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



import random
from typing import Callable


def backoff_linear_with_jitter(wait_time: float, jitter: float) -> Callable[[int], float]:
    def func(attempt: int) -> float:  # pylint: disable=unused-argument
        multiplier = jitter * (random.random() * 2 - 1)
        return wait_time * (1 + multiplier)

    return func


def backoff_exponential_with_jitter(base: float, cap: float) -> Callable[[int], float]:
    def func(attempt: int) -> float:  # pylint: disable=unused-argument
        try:
            res = (2**attempt) * base * random.random()
        except OverflowError:
            return cap

        if res > cap:
            return cap

        return res

    return func


def backoff_exponential_jittered_min_interval(base: float = 0.05, cap: float = 60) -> Callable[[int], float]:
    def func(attempt: int) -> float:  # pylint: disable=unused-argument
        try:
            base_interval = (2**attempt) * base
            res = base_interval / 2 + base_interval * random.random()
        except OverflowError:
            return cap

        if res > cap:
            return cap

        return res

    return func


def default_backoff() -> Callable[[int], float]:
    return backoff_exponential_with_jitter(0.05, 60)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Thumbnail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the thumbnail."""
    channel_id: builtins.str
    """ID of the channel where the thumbnail was created."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when thumbnail was created."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "created_at", b"created_at", "id", b"id"]) -> None: ...

global___Thumbnail = Thumbnail



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/talk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.speechsense.v1.analysis import conversation_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_conversation__statistics__pb2
from yandex.cloud.speechsense.v1.analysis import interrupts_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_interrupts__statistics__pb2
from yandex.cloud.speechsense.v1.analysis import silence_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_silence__statistics__pb2
from yandex.cloud.speechsense.v1.analysis import speech_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_speech__statistics__pb2
from yandex.cloud.speechsense.v1.analysis import summarization_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_summarization__pb2
from yandex.cloud.speechsense.v1.analysis import transcription_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_transcription__pb2
from yandex.cloud.speechsense.v1.analysis import text_classifiers_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_text__classifiers__pb2
from yandex.cloud.speechsense.v1.analysis import points_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_points__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/speechsense/v1/talk.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x42yandex/cloud/speechsense/v1/analysis/conversation_statistics.proto\x1a@yandex/cloud/speechsense/v1/analysis/interrupts_statistics.proto\x1a=yandex/cloud/speechsense/v1/analysis/silence_statistics.proto\x1a<yandex/cloud/speechsense/v1/analysis/speech_statistics.proto\x1a\x38yandex/cloud/speechsense/v1/analysis/summarization.proto\x1a\x38yandex/cloud/speechsense/v1/analysis/transcription.proto\x1a;yandex/cloud/speechsense/v1/analysis/text_classifiers.proto\x1a\x31yandex/cloud/speechsense/v1/analysis/points.proto\"\xf1\x07\n\x04Talk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x10\n\x08space_id\x18\x03 \x01(\t\x12\x15\n\rconnection_id\x18\x04 \x01(\t\x12\x13\n\x0bproject_ids\x18\x05 \x03(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bmodified_by\x18\x08 \x01(\t\x12/\n\x0bmodified_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0btalk_fields\x18\n \x03(\x0b\x32\".yandex.cloud.speechsense.v1.Field\x12J\n\rtranscription\x18\x0b \x01(\x0b\x32\x33.yandex.cloud.speechsense.v1.analysis.Transcription\x12Q\n\x11speech_statistics\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.speechsense.v1.analysis.SpeechStatistics\x12S\n\x12silence_statistics\x18\r \x01(\x0b\x32\x37.yandex.cloud.speechsense.v1.analysis.SilenceStatistics\x12Y\n\x15interrupts_statistics\x18\x0e \x01(\x0b\x32:.yandex.cloud.speechsense.v1.analysis.InterruptsStatistics\x12]\n\x17\x63onversation_statistics\x18\x0f \x01(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.ConversationStatistics\x12<\n\x06points\x18\x10 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.analysis.Points\x12O\n\x10text_classifiers\x18\x11 \x01(\x0b\x32\x35.yandex.cloud.speechsense.v1.analysis.TextClassifiers\x12J\n\rsummarization\x18\x12 \x01(\x0b\x32\x33.yandex.cloud.speechsense.v1.analysis.Summarization\x12:\n\ntalk_state\x18\x13 \x01(\x0b\x32&.yandex.cloud.speechsense.v1.TalkState\"\xad\x01\n\tTalkState\x12\x46\n\x10processing_state\x18\x01 \x01(\x0e\x32,.yandex.cloud.speechsense.v1.ProcessingState\x12X\n\x1a\x61lgorithm_processing_infos\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.speechsense.v1.AlgorithmProcessingInfo\"Z\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x34\n\x04type\x18\x03 \x01(\x0e\x32&.yandex.cloud.speechsense.v1.FieldType\"\x9c\x01\n\x17\x41lgorithmProcessingInfo\x12\x39\n\talgorithm\x18\x01 \x01(\x0e\x32&.yandex.cloud.speechsense.v1.Algorithm\x12\x46\n\x10processing_state\x18\x02 \x01(\x0e\x32,.yandex.cloud.speechsense.v1.ProcessingState*\xaf\x01\n\tFieldType\x12\x1a\n\x16\x46IELD_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x46IELD_TYPE_STRING\x10\x01\x12\x15\n\x11\x46IELD_TYPE_NUMBER\x10\x02\x12\x16\n\x12\x46IELD_TYPE_DECIMAL\x10\x03\x12\x16\n\x12\x46IELD_TYPE_BOOLEAN\x10\x04\x12\x13\n\x0f\x46IELD_TYPE_DATE\x10\x05\x12\x13\n\x0f\x46IELD_TYPE_JSON\x10\x06*\xb1\x01\n\x0fProcessingState\x12 \n\x1cPROCESSING_STATE_UNSPECIFIED\x10\x00\x12 \n\x1cPROCESSING_STATE_NOT_STARTED\x10\x01\x12\x1f\n\x1bPROCESSING_STATE_PROCESSING\x10\x02\x12\x1c\n\x18PROCESSING_STATE_SUCCESS\x10\x03\x12\x1b\n\x17PROCESSING_STATE_FAILED\x10\x04*\xbd\x01\n\tAlgorithm\x12\x19\n\x15\x41LGORITHM_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41LGORITHM_SPEECHKIT\x10\x01\x12\x12\n\x0e\x41LGORITHM_YGPT\x10\x02\x12\x18\n\x14\x41LGORITHM_CLASSIFIER\x10\x03\x12\x1b\n\x17\x41LGORITHM_SUMMARIZATION\x10\x04\x12\x17\n\x13\x41LGORITHM_EMBEDDING\x10\x05\x12\x18\n\x14\x41LGORITHM_STATISTICS\x10\x06\x42y\n\x1fyandex.cloud.api.speechsense.v1B\tTalkProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.talk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\tTalkProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_FIELDTYPE']._serialized_start=2031
  _globals['_FIELDTYPE']._serialized_end=2206
  _globals['_PROCESSINGSTATE']._serialized_start=2209
  _globals['_PROCESSINGSTATE']._serialized_end=2386
  _globals['_ALGORITHM']._serialized_start=2389
  _globals['_ALGORITHM']._serialized_end=2578
  _globals['_TALK']._serialized_start=592
  _globals['_TALK']._serialized_end=1601
  _globals['_TALKSTATE']._serialized_start=1604
  _globals['_TALKSTATE']._serialized_end=1777
  _globals['_FIELD']._serialized_start=1779
  _globals['_FIELD']._serialized_end=1869
  _globals['_ALGORITHMPROCESSINGINFO']._serialized_start=1872
  _globals['_ALGORITHMPROCESSINGINFO']._serialized_end=2028
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/foundation_models/v1/image_generation/image_generation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLyandex/cloud/ai/foundation_models/v1/image_generation/image_generation.proto\x12\x35yandex.cloud.ai.foundation_models.v1.image_generation\"\'\n\x07Message\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\"8\n\x0b\x41spectRatio\x12\x13\n\x0bwidth_ratio\x18\x01 \x01(\x03\x12\x14\n\x0cheight_ratio\x18\x02 \x01(\x03\"\x93\x01\n\x16ImageGenerationOptions\x12\x11\n\tmime_type\x18\x01 \x01(\t\x12\x0c\n\x04seed\x18\x02 \x01(\x03\x12X\n\x0c\x61spect_ratio\x18\x03 \x01(\x0b\x32\x42.yandex.cloud.ai.foundation_models.v1.image_generation.AspectRatioB\xa7\x01\n9yandex.cloud.api.ai.foundation_models.v1.image_generationZjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/image_generation;image_generationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9yandex.cloud.api.ai.foundation_models.v1.image_generationZjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/image_generation;image_generation'
  _globals['_MESSAGE']._serialized_start=135
  _globals['_MESSAGE']._serialized_end=174
  _globals['_ASPECTRATIO']._serialized_start=176
  _globals['_ASPECTRATIO']._serialized_end=232
  _globals['_IMAGEGENERATIONOPTIONS']._serialized_start=235
  _globals['_IMAGEGENERATIONOPTIONS']._serialized_end=382
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/gateway_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1 import gateway_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_gateway__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/vpc/v1/gateway_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a!yandex/cloud/vpc/v1/gateway.proto\"5\n\x11GetGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListGatewaysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"_\n\x14ListGatewaysResponse\x12.\n\x08gateways\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Gateway\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListGatewayOperationsRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListGatewayOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x19\n\x17SharedEgressGatewaySpec\"\xa6\x03\n\x14\x43reateGatewayRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12R\n\x1ashared_egress_gateway_spec\x18\x05 \x01(\x0b\x32,.yandex.cloud.vpc.v1.SharedEgressGatewaySpecH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07gateway\"+\n\x15\x43reateGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t\"\xd8\x03\n\x14UpdateGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12R\n\x1ashared_egress_gateway_spec\x18\x06 \x01(\x0b\x32,.yandex.cloud.vpc.v1.SharedEgressGatewaySpecH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07gateway\"+\n\x15UpdateGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t\"c\n\x12MoveGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t2\xc0\x08\n\x0eGatewayService\x12r\n\x03Get\x12&.yandex.cloud.vpc.v1.GetGatewayRequest\x1a\x1c.yandex.cloud.vpc.v1.Gateway\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/vpc/v1/gateways/{gateway_id}\x12u\n\x04List\x12(.yandex.cloud.vpc.v1.ListGatewaysRequest\x1a).yandex.cloud.vpc.v1.ListGatewaysResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/vpc/v1/gateways\x12\x97\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateGatewayRequest\x1a!.yandex.cloud.operation.Operation\"?\xb2\xd2* \n\x15\x43reateGatewayMetadata\x12\x07Gateway\x82\xd3\xe4\x93\x02\x15\"\x10/vpc/v1/gateways:\x01*\x12\xa4\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateGatewayRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2* \n\x15UpdateGatewayMetadata\x12\x07Gateway\x82\xd3\xe4\x93\x02\"2\x1d/vpc/v1/gateways/{gateway_id}:\x01*\x12\xaf\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteGatewayRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*.\n\x15\x44\x65leteGatewayMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f*\x1d/vpc/v1/gateways/{gateway_id}\x12\xa9\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListGatewayOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListGatewayOperationsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/vpc/v1/gateways/{gateway_id}/operations\x12\xa3\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveGatewayRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*\x1e\n\x13MoveGatewayMetadata\x12\x07Gateway\x82\xd3\xe4\x93\x02\'\"\"/vpc/v1/gateways/{gateway_id}:move:\x01*BV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.gateway_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _GETGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
  _GETGATEWAYREQUEST.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGATEWAYSREQUEST.fields_by_name['folder_id']._options = None
  _LISTGATEWAYSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGATEWAYSREQUEST.fields_by_name['page_size']._options = None
  _LISTGATEWAYSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTGATEWAYSREQUEST.fields_by_name['page_token']._options = None
  _LISTGATEWAYSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTGATEWAYSREQUEST.fields_by_name['filter']._options = None
  _LISTGATEWAYSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTGATEWAYOPERATIONSREQUEST.fields_by_name['gateway_id']._options = None
  _LISTGATEWAYOPERATIONSREQUEST.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGATEWAYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTGATEWAYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTGATEWAYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTGATEWAYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEGATEWAYREQUEST_LABELSENTRY._options = None
  _CREATEGATEWAYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEGATEWAYREQUEST.fields_by_name['folder_id']._options = None
  _CREATEGATEWAYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEGATEWAYREQUEST.fields_by_name['name']._options = None
  _CREATEGATEWAYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEGATEWAYREQUEST.fields_by_name['description']._options = None
  _CREATEGATEWAYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEGATEWAYREQUEST.fields_by_name['labels']._options = None
  _CREATEGATEWAYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEGATEWAYREQUEST_LABELSENTRY._options = None
  _UPDATEGATEWAYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
  _UPDATEGATEWAYREQUEST.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEGATEWAYREQUEST.fields_by_name['name']._options = None
  _UPDATEGATEWAYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEGATEWAYREQUEST.fields_by_name['description']._options = None
  _UPDATEGATEWAYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEGATEWAYREQUEST.fields_by_name['labels']._options = None
  _UPDATEGATEWAYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
  _DELETEGATEWAYREQUEST.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
  _MOVEGATEWAYREQUEST.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEGATEWAYREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEGATEWAYREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GATEWAYSERVICE.methods_by_name['Get']._options = None
  _GATEWAYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/vpc/v1/gateways/{gateway_id}'
  _GATEWAYSERVICE.methods_by_name['List']._options = None
  _GATEWAYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/vpc/v1/gateways'
  _GATEWAYSERVICE.methods_by_name['Create']._options = None
  _GATEWAYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateGatewayMetadata\022\007Gateway\202\323\344\223\002\025\"\020/vpc/v1/gateways:\001*'
  _GATEWAYSERVICE.methods_by_name['Update']._options = None
  _GATEWAYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateGatewayMetadata\022\007Gateway\202\323\344\223\002\"2\035/vpc/v1/gateways/{gateway_id}:\001*'
  _GATEWAYSERVICE.methods_by_name['Delete']._options = None
  _GATEWAYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteGatewayMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037*\035/vpc/v1/gateways/{gateway_id}'
  _GATEWAYSERVICE.methods_by_name['ListOperations']._options = None
  _GATEWAYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002*\022(/vpc/v1/gateways/{gateway_id}/operations'
  _GATEWAYSERVICE.methods_by_name['Move']._options = None
  _GATEWAYSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveGatewayMetadata\022\007Gateway\202\323\344\223\002\'\"\"/vpc/v1/gateways/{gateway_id}:move:\001*'
  _globals['_GETGATEWAYREQUEST']._serialized_start=270
  _globals['_GETGATEWAYREQUEST']._serialized_end=323
  _globals['_LISTGATEWAYSREQUEST']._serialized_start=326
  _globals['_LISTGATEWAYSREQUEST']._serialized_end=470
  _globals['_LISTGATEWAYSRESPONSE']._serialized_start=472
  _globals['_LISTGATEWAYSRESPONSE']._serialized_end=567
  _globals['_LISTGATEWAYOPERATIONSREQUEST']._serialized_start=569
  _globals['_LISTGATEWAYOPERATIONSREQUEST']._serialized_end=695
  _globals['_LISTGATEWAYOPERATIONSRESPONSE']._serialized_start=697
  _globals['_LISTGATEWAYOPERATIONSRESPONSE']._serialized_end=808
  _globals['_SHAREDEGRESSGATEWAYSPEC']._serialized_start=810
  _globals['_SHAREDEGRESSGATEWAYSPEC']._serialized_end=835
  _globals['_CREATEGATEWAYREQUEST']._serialized_start=838
  _globals['_CREATEGATEWAYREQUEST']._serialized_end=1260
  _globals['_CREATEGATEWAYREQUEST_LABELSENTRY']._serialized_start=1204
  _globals['_CREATEGATEWAYREQUEST_LABELSENTRY']._serialized_end=1249
  _globals['_CREATEGATEWAYMETADATA']._serialized_start=1262
  _globals['_CREATEGATEWAYMETADATA']._serialized_end=1305
  _globals['_UPDATEGATEWAYREQUEST']._serialized_start=1308
  _globals['_UPDATEGATEWAYREQUEST']._serialized_end=1780
  _globals['_UPDATEGATEWAYREQUEST_LABELSENTRY']._serialized_start=1204
  _globals['_UPDATEGATEWAYREQUEST_LABELSENTRY']._serialized_end=1249
  _globals['_UPDATEGATEWAYMETADATA']._serialized_start=1782
  _globals['_UPDATEGATEWAYMETADATA']._serialized_end=1825
  _globals['_DELETEGATEWAYREQUEST']._serialized_start=1827
  _globals['_DELETEGATEWAYREQUEST']._serialized_end=1883
  _globals['_DELETEGATEWAYMETADATA']._serialized_start=1885
  _globals['_DELETEGATEWAYMETADATA']._serialized_end=1928
  _globals['_MOVEGATEWAYREQUEST']._serialized_start=1930
  _globals['_MOVEGATEWAYREQUEST']._serialized_end=2029
  _globals['_MOVEGATEWAYMETADATA']._serialized_start=2031
  _globals['_MOVEGATEWAYMETADATA']._serialized_end=2072
  _globals['_GATEWAYSERVICE']._serialized_start=2075
  _globals['_GATEWAYSERVICE']._serialized_end=3163
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/reference/reference.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/reference/reference.proto\x12\x16yandex.cloud.reference\"\xb0\x01\n\tReference\x12\x32\n\x08referrer\x18\x01 \x01(\x0b\x32 .yandex.cloud.reference.Referrer\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.yandex.cloud.reference.Reference.Type\"9\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nMANAGED_BY\x10\x01\x12\x0b\n\x07USED_BY\x10\x02\"$\n\x08Referrer\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\tBb\n\x1ayandex.cloud.api.referenceZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/reference;referenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.reference.reference_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.referenceZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/reference;reference'
  _globals['_REFERENCE']._serialized_start=67
  _globals['_REFERENCE']._serialized_end=243
  _globals['_REFERENCE_TYPE']._serialized_start=186
  _globals['_REFERENCE_TYPE']._serialized_end=243
  _globals['_REFERRER']._serialized_start=245
  _globals['_REFERRER']._serialized_end=281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/playlist.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/video/v1/playlist.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe8\x01\n\x08Playlist\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x32\n\x05items\x18\x05 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItem\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x06\x10\x64\"V\n\x0cPlaylistItem\x12\x12\n\x08video_id\x18\x64 \x01(\tH\x00\x12\x14\n\nepisode_id\x18\x65 \x01(\tH\x00\x12\x10\n\x08position\x18\x01 \x01(\x03\x42\x04\n\x02idJ\x04\x08\x02\x10\x64\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.playlist_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_PLAYLIST']._serialized_start=97
  _globals['_PLAYLIST']._serialized_end=329
  _globals['_PLAYLISTITEM']._serialized_start=331
  _globals['_PLAYLISTITEM']._serialized_end=417
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/export_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.logging.v1 import export_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_export__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/logging/v1/export_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a$yandex/cloud/logging/v1/export.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x8f\x02\n\x10RunExportRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\x07sink_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12;\n\x06params\x18\x03 \x01(\x0b\x32%.yandex.cloud.logging.v1.ExportParamsB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0fresult_filename\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x05since\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12/\n\x05until\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\"\xdb\x01\n\x10RunExportDetails\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x0f\n\x07sink_id\x18\x02 \x01(\t\x12\x35\n\x06params\x18\x03 \x01(\x0b\x32%.yandex.cloud.logging.v1.ExportParams\x12\x17\n\x0fresult_filename\x18\x04 \x01(\t\x12)\n\x05since\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05until\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\x11RunExportMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x0f\n\x07sink_id\x18\x02 \x01(\t\x12\x17\n\x0fresult_filename\x18\x03 \x01(\t\"3\n\x10GetExportRequest\x12\x1f\n\texport_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x89\x01\n\x12ListExportsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x03\"`\n\x13ListExportsResponse\x12\x30\n\x07\x65xports\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.logging.v1.Export\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xba\x03\n\x13\x43reateExportRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x85\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x38.yandex.cloud.logging.v1.CreateExportRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1e\n\x08group_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\x07sink_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12;\n\x06params\x18\x07 \x01(\x0b\x32%.yandex.cloud.logging.v1.ExportParamsB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14\x43reateExportMetadata\x12\x11\n\texport_id\x18\x01 \x01(\t\"\xeb\x03\n\x13UpdateExportRequest\x12\x1f\n\texport_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x38.yandex.cloud.logging.v1.UpdateExportRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1e\n\x08group_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\x07sink_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12;\n\x06params\x18\x08 \x01(\x0b\x32%.yandex.cloud.logging.v1.ExportParamsB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateExportMetadata\x12\x11\n\texport_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteExportRequest\x12\x1f\n\texport_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\")\n\x14\x44\x65leteExportMetadata\x12\x11\n\texport_id\x18\x01 \x01(\t\"\x98\x01\n\x1bListExportOperationsRequest\x12\x1f\n\texport_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"n\n\x1cListExportOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xec\r\n\rExportService\x12\x9f\x01\n\x03Run\x12).yandex.cloud.logging.v1.RunExportRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2*%\n\x11RunExportMetadata\x12\x10RunExportDetails\x82\xd3\xe4\x93\x02\x1b\"\x16/logging/v1/run-export:\x01*\x12z\n\x03Get\x12).yandex.cloud.logging.v1.GetExportRequest\x1a\x1f.yandex.cloud.logging.v1.Export\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/logging/v1/exports/{export_id}\x12~\n\x04List\x12+.yandex.cloud.logging.v1.ListExportsRequest\x1a,.yandex.cloud.logging.v1.ListExportsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/logging/v1/exports\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.logging.v1.CreateExportRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reateExportMetadata\x12\x06\x45xport\x82\xd3\xe4\x93\x02\x18\"\x13/logging/v1/exports:\x01*\x12\xa7\x01\n\x06Update\x12,.yandex.cloud.logging.v1.UpdateExportRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*\x1e\n\x14UpdateExportMetadata\x12\x06\x45xport\x82\xd3\xe4\x93\x02$2\x1f/logging/v1/exports/{export_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12,.yandex.cloud.logging.v1.DeleteExportRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*-\n\x14\x44\x65leteExportMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/logging/v1/exports/{export_id}\x12\xb1\x01\n\x0eListOperations\x12\x34.yandex.cloud.logging.v1.ListExportOperationsRequest\x1a\x35.yandex.cloud.logging.v1.ListExportOperationsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/logging/v1/exports/{export_id}/operations\x12\xb3\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/logging/v1/exports/{resource_id}:listAccessBindings\x12\xe2\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x38\"3/logging/v1/exports/{resource_id}:setAccessBindings:\x01*\x12\xef\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;26/logging/v1/exports/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.export_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _RUNEXPORTREQUEST.fields_by_name['group_id']._options = None
  _RUNEXPORTREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _RUNEXPORTREQUEST.fields_by_name['sink_id']._options = None
  _RUNEXPORTREQUEST.fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _RUNEXPORTREQUEST.fields_by_name['params']._options = None
  _RUNEXPORTREQUEST.fields_by_name['params']._serialized_options = b'\350\3071\001'
  _RUNEXPORTREQUEST.fields_by_name['result_filename']._options = None
  _RUNEXPORTREQUEST.fields_by_name['result_filename']._serialized_options = b'\350\3071\001'
  _RUNEXPORTREQUEST.fields_by_name['since']._options = None
  _RUNEXPORTREQUEST.fields_by_name['since']._serialized_options = b'\350\3071\001'
  _RUNEXPORTREQUEST.fields_by_name['until']._options = None
  _RUNEXPORTREQUEST.fields_by_name['until']._serialized_options = b'\350\3071\001'
  _GETEXPORTREQUEST.fields_by_name['export_id']._options = None
  _GETEXPORTREQUEST.fields_by_name['export_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTEXPORTSREQUEST.fields_by_name['folder_id']._options = None
  _LISTEXPORTSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTEXPORTSREQUEST.fields_by_name['page_token']._options = None
  _LISTEXPORTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTEXPORTSREQUEST.fields_by_name['filter']._options = None
  _LISTEXPORTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATEEXPORTREQUEST_LABELSENTRY._options = None
  _CREATEEXPORTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEEXPORTREQUEST.fields_by_name['folder_id']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _CREATEEXPORTREQUEST.fields_by_name['name']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEEXPORTREQUEST.fields_by_name['description']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEEXPORTREQUEST.fields_by_name['labels']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATEEXPORTREQUEST.fields_by_name['group_id']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _CREATEEXPORTREQUEST.fields_by_name['sink_id']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _CREATEEXPORTREQUEST.fields_by_name['params']._options = None
  _CREATEEXPORTREQUEST.fields_by_name['params']._serialized_options = b'\350\3071\001'
  _UPDATEEXPORTREQUEST_LABELSENTRY._options = None
  _UPDATEEXPORTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEEXPORTREQUEST.fields_by_name['export_id']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['export_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _UPDATEEXPORTREQUEST.fields_by_name['name']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATEEXPORTREQUEST.fields_by_name['description']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEEXPORTREQUEST.fields_by_name['labels']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATEEXPORTREQUEST.fields_by_name['group_id']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _UPDATEEXPORTREQUEST.fields_by_name['sink_id']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _UPDATEEXPORTREQUEST.fields_by_name['params']._options = None
  _UPDATEEXPORTREQUEST.fields_by_name['params']._serialized_options = b'\350\3071\001'
  _DELETEEXPORTREQUEST.fields_by_name['export_id']._options = None
  _DELETEEXPORTREQUEST.fields_by_name['export_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['export_id']._options = None
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['export_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTEXPORTOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _EXPORTSERVICE.methods_by_name['Run']._options = None
  _EXPORTSERVICE.methods_by_name['Run']._serialized_options = b'\262\322*%\n\021RunExportMetadata\022\020RunExportDetails\202\323\344\223\002\033\"\026/logging/v1/run-export:\001*'
  _EXPORTSERVICE.methods_by_name['Get']._options = None
  _EXPORTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/logging/v1/exports/{export_id}'
  _EXPORTSERVICE.methods_by_name['List']._options = None
  _EXPORTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/logging/v1/exports'
  _EXPORTSERVICE.methods_by_name['Create']._options = None
  _EXPORTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateExportMetadata\022\006Export\202\323\344\223\002\030\"\023/logging/v1/exports:\001*'
  _EXPORTSERVICE.methods_by_name['Update']._options = None
  _EXPORTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateExportMetadata\022\006Export\202\323\344\223\002$2\037/logging/v1/exports/{export_id}:\001*'
  _EXPORTSERVICE.methods_by_name['Delete']._options = None
  _EXPORTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteExportMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/logging/v1/exports/{export_id}'
  _EXPORTSERVICE.methods_by_name['ListOperations']._options = None
  _EXPORTSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002,\022*/logging/v1/exports/{export_id}/operations'
  _EXPORTSERVICE.methods_by_name['ListAccessBindings']._options = None
  _EXPORTSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0026\0224/logging/v1/exports/{resource_id}:listAccessBindings'
  _EXPORTSERVICE.methods_by_name['SetAccessBindings']._options = None
  _EXPORTSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0028\"3/logging/v1/exports/{resource_id}:setAccessBindings:\001*'
  _EXPORTSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _EXPORTSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002;26/logging/v1/exports/{resource_id}:updateAccessBindings:\001*'
  _globals['_RUNEXPORTREQUEST']._serialized_start=348
  _globals['_RUNEXPORTREQUEST']._serialized_end=619
  _globals['_RUNEXPORTDETAILS']._serialized_start=622
  _globals['_RUNEXPORTDETAILS']._serialized_end=841
  _globals['_RUNEXPORTMETADATA']._serialized_start=843
  _globals['_RUNEXPORTMETADATA']._serialized_end=922
  _globals['_GETEXPORTREQUEST']._serialized_start=924
  _globals['_GETEXPORTREQUEST']._serialized_end=975
  _globals['_LISTEXPORTSREQUEST']._serialized_start=978
  _globals['_LISTEXPORTSREQUEST']._serialized_end=1115
  _globals['_LISTEXPORTSRESPONSE']._serialized_start=1117
  _globals['_LISTEXPORTSRESPONSE']._serialized_end=1213
  _globals['_CREATEEXPORTREQUEST']._serialized_start=1216
  _globals['_CREATEEXPORTREQUEST']._serialized_end=1658
  _globals['_CREATEEXPORTREQUEST_LABELSENTRY']._serialized_start=1613
  _globals['_CREATEEXPORTREQUEST_LABELSENTRY']._serialized_end=1658
  _globals['_CREATEEXPORTMETADATA']._serialized_start=1660
  _globals['_CREATEEXPORTMETADATA']._serialized_end=1701
  _globals['_UPDATEEXPORTREQUEST']._serialized_start=1704
  _globals['_UPDATEEXPORTREQUEST']._serialized_end=2195
  _globals['_UPDATEEXPORTREQUEST_LABELSENTRY']._serialized_start=1613
  _globals['_UPDATEEXPORTREQUEST_LABELSENTRY']._serialized_end=1658
  _globals['_UPDATEEXPORTMETADATA']._serialized_start=2197
  _globals['_UPDATEEXPORTMETADATA']._serialized_end=2238
  _globals['_DELETEEXPORTREQUEST']._serialized_start=2240
  _globals['_DELETEEXPORTREQUEST']._serialized_end=2294
  _globals['_DELETEEXPORTMETADATA']._serialized_start=2296
  _globals['_DELETEEXPORTMETADATA']._serialized_end=2337
  _globals['_LISTEXPORTOPERATIONSREQUEST']._serialized_start=2340
  _globals['_LISTEXPORTOPERATIONSREQUEST']._serialized_end=2492
  _globals['_LISTEXPORTOPERATIONSRESPONSE']._serialized_start=2494
  _globals['_LISTEXPORTOPERATIONSRESPONSE']._serialized_end=2604
  _globals['_EXPORTSERVICE']._serialized_start=2607
  _globals['_EXPORTSERVICE']._serialized_end=4379
# @@protoc_insertion_point(module_scope)
